Crate non_empty_str

Crate non_empty_str 

Non-empty strings.

Modules

boxed
Non-empty Box<str>.
cow
Non-empty Cow<'_, str>.
iter
Various iterators over non-empty strings.
macros
Macros for creating non-empty strings.
str
Non-empty str.
string
Non-empty String.

Macros

const_non_empty_str
Similar to non_empty_str! but for const contexts.
non_empty_str
Constructs NonEmptyStr from the given string, panicking if it is empty.
non_empty_stringalloc or std
Constructs NonEmptyStr from the given string, panicking if it is empty, and then converts it into NonEmptyString.

Structs

EmptyBoxedStr
Similar to EmptyString, but contains the empty boxed string provided.
EmptyStr
Represents errors returned when received strings are empty.
EmptyString
Similar to EmptyStr, but holds the empty string provided.
FromNonEmptyUtf8Error
Couples NonEmptyUtf8Error with the NonEmptyByteVec that is invalid UTF-8.
NonEmptyStr
Represents non-empty str values.
NonEmptyString
Represents non-empty String values.
NonEmptyUtf8Error
Represents errors returned when the received non-empty bytes are not valid UTF-8.

Enums

FromMaybeEmptyUtf8Error
Represents errors returned when the provided byte vector is empty or invalid UTF-8.
MaybeEmptyUtf8Error
Represents errors returned when the received bytes are either empty or not valid UTF-8.

Traits

FromNonEmptyStr
Parsing values from non-empty strings.

Type Aliases

NonEmptyBoxedStr
Represents non-empty boxed strings, Box<NonEmptyStr>.
NonEmptyCowStr
Represents non-empty clone-on-write strings, Cow<'s, NonEmptyStr>.