Crate non_empty_str

Crate non_empty_str 

Non-empty strings.

Modules

boxedalloc or std
Non-empty Box<str>.
cowalloc or std
Non-empty Cow<'_, str>.
iter
Various iterators over non-empty strings.
macros
Macros for creating non-empty strings.
str
Non-empty str.
stringalloc or std
Non-empty String.

Macros

const_non_empty_str
Similar to non_empty_str! but for const contexts.
non_empty_str
Constructs NonEmptyStr from the given string, panicking if the it is empty.

Structs

EmptyBoxedStralloc or std
Similar to EmptyString, but contains the empty boxed string provided.
EmptyStr
Represents errors returned when received strings are empty.
EmptyStringalloc or std
Similar to EmptyStr, but holds the empty string provided.
FromNonEmptyUtf8Erroralloc or std
Couples NonEmptyUtf8Error with the NonEmptyByteVec that is invalid UTF-8.
NonEmptyStr
Represents non-empty str values.
NonEmptyStringalloc or std
Represents non-empty String values.
NonEmptyUtf8Error
Represents errors returned when the received non-empty bytes are not valid UTF-8.

Enums

FromMaybeEmptyUtf8Erroralloc or std
Represents errors returned when the provided byte vector is empty or invalid UTF-8.
MaybeEmptyUtf8Error
Represents errors returned when the received bytes are either empty or not valid UTF-8.

Traits

FromNonEmptyStr
Parsing values from non-empty strings.

Type Aliases

NonEmptyBoxedStralloc or std
Represents non-empty boxed strings, Box<NonEmptyStr>.
NonEmptyCowStralloc or std
Represents non-empty clone-on-write strings, Cow<'_, NonEmptyStr>.